==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/datashare/kotlin/outputs/GetKustoTableDataSetMappingResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datashare.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * A Kusto database data set mapping
 * @property dataSetId The id of the source data set.
 * @property dataSetMappingStatus Gets the status of the data set mapping.
 * @property id The resource id of the azure resource
 * @property kind Kind of data set mapping.
 * Expected value is 'KustoTable'.
 * @property kustoClusterResourceId Resource id of the sink kusto cluster.
 * @property location Location of the sink kusto cluster.
 * @property name Name of the azure resource
 * @property provisioningState Provisioning state of the data set mapping.
 * @property systemData System Data of the Azure resource.
 * @property type Type of the azure resource
 */
public data class GetKustoTableDataSetMappingResult(
    public val dataSetId: String,
    public val dataSetMappingStatus: String,
    public val id: String,
    public val kind: String,
    public val kustoClusterResourceId: String,
    public val location: String,
    public val name: String,
    public val provisioningState: String,
    public val systemData: SystemDataResponse,
    public val type: String,
) {
    public companion object {
        public
        fun toKotlin(javaType: com.pulumi.azurenative.datashare.outputs.GetKustoTableDataSetMappingResult):
            GetKustoTableDataSetMappingResult = GetKustoTableDataSetMappingResult(
            dataSetId = javaType.dataSetId(),
            dataSetMappingStatus = javaType.dataSetMappingStatus(),
            id = javaType.id(),
            kind = javaType.kind(),
            kustoClusterResourceId = javaType.kustoClusterResourceId(),
            location = javaType.location(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.datashare.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            type = javaType.type(),
        )
    }
}

==> pulumi-azure-native-kotlin-2.44.1.0-sources.jar: com/pulumi/azurenative/datashare/kotlin/outputs/GetKustoTableDataSetMappingResult.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.datashare.kotlin.outputs

import kotlin.String
import kotlin.Suppress

/**
 * A Kusto database data set mapping
 * @property dataSetId The id of the source data set.
 * @property dataSetMappingStatus Gets the status of the data set mapping.
 * @property id The resource id of the azure resource
 * @property kind Kind of data set mapping.
 * Expected value is 'KustoTable'.
 * @property kustoClusterResourceId Resource id of the sink kusto cluster.
 * @property location Location of the sink kusto cluster.
 * @property name Name of the azure resource
 * @property provisioningState Provisioning state of the data set mapping.
 * @property systemData System Data of the Azure resource.
 * @property type Type of the azure resource
 */
public data class GetKustoTableDataSetMappingResult(
    public val dataSetId: String,
    public val dataSetMappingStatus: String,
    public val id: String,
    public val kind: String,
    public val kustoClusterResourceId: String,
    public val location: String,
    public val name: String,
    public val provisioningState: String,
    public val systemData: SystemDataResponse,
    public val type: String,
) {
    public companion object {
        public fun toKotlin(javaType: com.pulumi.azurenative.datashare.outputs.GetKustoTableDataSetMappingResult): GetKustoTableDataSetMappingResult = GetKustoTableDataSetMappingResult(
            dataSetId = javaType.dataSetId(),
            dataSetMappingStatus = javaType.dataSetMappingStatus(),
            id = javaType.id(),
            kind = javaType.kind(),
            kustoClusterResourceId = javaType.kustoClusterResourceId(),
            location = javaType.location(),
            name = javaType.name(),
            provisioningState = javaType.provisioningState(),
            systemData = javaType.systemData().let({ args0 ->
                com.pulumi.azurenative.datashare.kotlin.outputs.SystemDataResponse.Companion.toKotlin(args0)
            }),
            type = javaType.type(),
        )
    }
}
